@@ -11,7 +11,7 @@ from hiten.algorithms.hamiltonian.hamiltonian import \
     _build_physical_hamiltonian
 from hiten.algorithms.hamiltonian.lie import (_apply_poly_transform,
                                               _solve_homological_equation)
-from hiten.algorithms.hamiltonian.transforms import (_local2realmodal,
+from hiten.algorithms.hamiltonian.transforms import (_polylocal2realmodal,
                                                      _substitute_complex)
 from hiten.algorithms.polynomial.algebra import _poly_poisson
 from hiten.algorithms.polynomial.base import (_create_encode_dict_from_clmo,
@@ -272,7 +272,7 @@ def test_lie_transform_on_center_manifold(lie_test_setup):
     max_degree = TEST_MAX_DEG
     
     H_phys = _build_physical_hamiltonian(point, max_degree)
-    H_rn = _local2realmodal(point, H_phys, max_degree, psi, clmo)
+    H_rn = _polylocal2realmodal(point, H_phys, max_degree, psi, clmo)
     H_cn = _substitute_complex(H_rn, max_degree, psi, clmo)
     
     poly_trans, _, _ = _lie_transform(point, H_cn, psi, clmo, max_degree)
@@ -323,7 +323,7 @@ def test_lie_expansion_accumulation(lie_test_setup):
     
     for max_deg in [3, 4, 5, 6]:
         H_phys = _build_physical_hamiltonian(point, 6)
-        H_rn = _local2realmodal(point, H_phys, 6, psi, clmo)
+        H_rn = _polylocal2realmodal(point, H_phys, 6, psi, clmo)
         H_cn = _substitute_complex(H_rn, 6, psi, clmo)
         _, poly_G_total, _ = _lie_transform(point, H_cn, psi, clmo, max_deg)
         
@@ -424,7 +424,7 @@ def test_lie_expansion_degree_scaling(lie_test_setup):
     
     # Build and normalize Hamiltonian for different degrees
     H_phys = _build_physical_hamiltonian(point, 6)  # Use max degree 6 for building
-    H_rn = _local2realmodal(point, H_phys, 6, psi, clmo)
+    H_rn = _polylocal2realmodal(point, H_phys, 6, psi, clmo)
     H_cn = _substitute_complex(H_rn, 6, psi, clmo)
     
     # Test point on center manifold
@@ -588,7 +588,7 @@ def test_lie_expansion_symplecticity(lie_test_setup):
     clmo = cm._clmo
     
     H_phys = _build_physical_hamiltonian(point, 6)
-    H_rn = _local2realmodal(point, H_phys, 6, psi, clmo)
+    H_rn = _polylocal2realmodal(point, H_phys, 6, psi, clmo)
     H_cn = _substitute_complex(H_rn, 6, psi, clmo)
     
     Omega = np.block([[np.zeros((3,3)),  np.eye(3)],
