@@ -19,7 +19,8 @@ manifolds near collinear libration points".
 """
 
 from dataclasses import asdict
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Tuple, Iterable, Union
+from typing import (TYPE_CHECKING, Any, Callable, Dict, Iterable, List, Tuple,
+                    Union)
 
 import numpy as np
 
@@ -32,14 +33,18 @@ from hiten.algorithms.hamiltonian.hamiltonian import \
 # Full ("complete") normal form Lie transform
 from hiten.algorithms.hamiltonian.normal._lie import \
     _lie_transform as _lie_transform_full
-from hiten.algorithms.hamiltonian.transforms import (_local2realmodal,
+from hiten.algorithms.hamiltonian.transforms import (_coordlocal2realmodal,
+                                                     _coordrealmodal2local,
                                                      _local2synodic_collinear,
                                                      _local2synodic_triangular,
-                                                     _realmodal2local,
+                                                     _polylocal2realmodal,
+                                                     _polyrealmodal2local,
                                                      _solve_complex,
                                                      _solve_real,
                                                      _substitute_complex,
-                                                     _substitute_real)
+                                                     _substitute_real,
+                                                     _synodic2local_collinear,
+                                                     _synodic2local_triangular)
 from hiten.algorithms.poincare.config import _get_section_config
 from hiten.algorithms.poincare.map import _solve_missing_coord
 from hiten.algorithms.polynomial.base import (_create_encode_dict_from_clmo,
@@ -95,12 +100,14 @@ class CenterManifold:
 
         if isinstance(self._point, CollinearPoint):
             self._local2synodic = _local2synodic_collinear
+            self._synodic2local = _synodic2local_collinear
 
             if isinstance(self._point, L3Point):
-                logger.warning("L3 point is not has not been verified for centre manifold computation!")
+                logger.warning("L3 point has not been verified for centre manifold computation!")
 
         elif isinstance(self._point, TriangularPoint):
             self._local2synodic = _local2synodic_triangular
+            self._synodic2local = _synodic2local_triangular
             err = "Triangular points not implemented for centre manifold computation!"
             logger.error(err)
             raise NotImplementedError(err)
@@ -172,17 +179,7 @@ class CenterManifold:
         # Mapping from *form* identifiers to the corresponding accessor
         # methods.  These accessors take care of computing and caching the
         # requested polynomial list on-demand.
-        _form_dispatch: dict[str, Callable[[], List[np.ndarray]]] = {
-            "physical": self._get_physical_hamiltonian,
-            "real_modal": self._get_real_modal_form,
-            "complex_modal": self._get_complex_modal_form,
-            "real_partial_normal": self._get_partial_real_normal_form,
-            "complex_partial_normal": self._get_complex_partial_normal_form,
-            "real_full_normal": self._get_full_real_normal_form,
-            "complex_full_normal": self._get_full_complex_normal_form,
-            "center_manifold_real": self._get_center_manifold_real,
-            "center_manifold_complex": self._get_center_manifold_complex,
-        }
+        _form_dispatch = self._get_form_dispatch()
 
         if form not in _form_dispatch:
             raise ValueError(
@@ -219,6 +216,25 @@ class CenterManifold:
         self._cache.clear()
         self._poincare_maps.clear()
 
+    def _get_form_dispatch(self) -> Dict[str, Callable[[], List[np.ndarray]]]:
+        """Return a dictionary mapping *form* strings to internal accessors.
+
+        This centralizes the mapping so it can be reused by both
+        :py:meth:`coefficients` and :py:meth:`compute` without repeating the
+        same dictionary definition in multiple places.
+        """
+        return {
+            "physical": self._get_physical_hamiltonian,
+            "real_modal": self._get_real_modal_form,
+            "complex_modal": self._get_complex_modal_form,
+            "real_partial_normal": self._get_partial_real_normal_form,
+            "complex_partial_normal": self._get_complex_partial_normal_form,
+            "real_full_normal": self._get_full_real_normal_form,
+            "complex_full_normal": self._get_full_complex_normal_form,
+            "center_manifold_real": self._get_center_manifold_real,
+            "center_manifold_complex": self._get_center_manifold_complex,
+        }
+
     def _get_or_compute(self, key: tuple, compute_func: Callable[[], Any]) -> Any:
         r"""
         Retrieve a value from the cache or compute it if not present.
@@ -257,7 +273,7 @@ class CenterManifold:
 
     def _get_real_modal_form(self) -> List[np.ndarray]:
         key = ('hamiltonian', self._max_degree, 'real_modal')
-        return self._get_or_compute(key, lambda: _local2realmodal(
+        return self._get_or_compute(key, lambda: _polylocal2realmodal(
             self._point, self._get_physical_hamiltonian(), self._max_degree, self._psi, self._clmo
         ))
 
@@ -367,7 +383,7 @@ class CenterManifold:
 
         return self._get_or_compute(key, compute_full_real_normal)
     
-    def _restrict_to_center_manifold(self, poly_H, tol=1e-14):
+    def _restrict_poly_to_center_manifold(self, poly_H, tol=1e-14):
         r"""
         Restrict a Hamiltonian to the center manifold by eliminating hyperbolic variables.
         """
@@ -384,12 +400,18 @@ class CenterManifold:
                     coeff_vec[pos] = 0.0
         return poly_cm
     
+    def _restrict_coord_to_center_manifold(self, coord_6d):
+        # Convert complex arrays with zero imaginary parts to real
+        if np.iscomplexobj(coord_6d):
+            coord_6d = np.real(coord_6d)
+        return np.array([0, coord_6d[1], coord_6d[2], 0, coord_6d[4], coord_6d[5]], dtype=np.float64)
+    
     def _get_center_manifold_complex(self) -> List[np.ndarray]:
         key = ('hamiltonian', self._max_degree, 'center_manifold_complex')
         
         def compute_cm_complex():
             poly_trans = self._get_complex_partial_normal_form()
-            return self._restrict_to_center_manifold(poly_trans)
+            return self._restrict_poly_to_center_manifold(poly_trans)
 
         return self._get_or_compute(key, compute_cm_complex)
 
@@ -402,20 +424,34 @@ class CenterManifold:
 
         return self._get_or_compute(key, compute_cm_real)
 
-    def compute(self) -> List[np.ndarray]:
+    def compute(self, form: str = "center_manifold_real") -> List[np.ndarray]:
         r"""
-        Compute the polynomial Hamiltonian restricted to the centre manifold.
+        Compute and return a specific polynomial representation of the
+        Hamiltonian.
 
-        The returned list lives in *real* coordinates
-        :math:`(q_2, p_2, q_3, p_3)`. This method serves as the main entry
-        point for the centre manifold computation pipeline, triggering lazy
-        computation and caching of all intermediate steps.
+        By default (``form='center_manifold_real'``) this reproduces the
+        historical behaviour of returning the Hamiltonian restricted to the
+        centre manifold expressed in real variables
+        :math:`(q_2, p_2, q_3, p_3)`.  However, any of the internally
+        supported representations can be requested by passing the appropriate
+        *form* key, enabling callers (e.g.
+        bifurcation/continuation routines) to obtain the *full* complex normal
+        form without performing extraneous computations.
+
+        Parameters
+        ----------
+        form : str, optional
+            Identifier of the desired polynomial representation.  Allowed
+            values are the same as those accepted by
+            :py:meth:`CenterManifold.coefficients`.  Defaults to
+            ``'center_manifold_real'`` for backward compatibility.
 
         Returns
         -------
         list of numpy.ndarray
-            Sequence :math:`[H_0, H_2, \dots, H_N]` where each entry contains the
-            packed coefficients of the homogeneous polynomial of that degree.
+            Sequence :math:`[H_0, H_2, \dots, H_N]` where each entry contains
+            the packed coefficients of the homogeneous polynomial of that
+            degree.
 
         Raises
         ------
@@ -424,11 +460,25 @@ class CenterManifold:
         
         Notes
         -----
-        This routine chains together the full normal-form pipeline and may be
-        computationally expensive on the first call. Intermediate objects are
-        cached so that subsequent calls are fast.
+        The computation is performed lazily and all intermediate results are
+        cached.  Subsequent calls with the same *form* are therefore
+        inexpensive.
         """
-        return self._get_center_manifold_real()
+
+        # Mapping reused from ``coefficients`` but returning *raw* coefficient
+        # lists instead of pretty-printed tables.
+        _form_dispatch = self._get_form_dispatch()
+
+        if form not in _form_dispatch:
+            raise ValueError(
+                f"Unsupported form '{form}'. Allowed values are: "
+                f"{', '.join(_form_dispatch.keys())}."
+            )
+
+        # Compute (or retrieve from cache) the requested representation.
+        result = _form_dispatch[form]()
+        logger.info(f"Computed {form} coefficients.")
+        return result
 
     def poincare_map(self, energy: float, **kwargs) -> "_PoincareMap":
         r"""
@@ -502,7 +552,7 @@ class CenterManifold:
         
         return self._poincare_maps[cache_key]
 
-    def ic(self, poincare_point: np.ndarray, energy: float, section_coord: str = "q3") -> np.ndarray:
+    def ic(self, poincare_point: np.ndarray, energy: float, section_coord: str = "q3", tol=1e-16) -> np.ndarray:
         r"""
         Convert a point on a 2-dimensional centre-manifold section to full ICs.
 
@@ -537,7 +587,7 @@ class CenterManifold:
         )
 
         # Ensure we have the centre-manifold Hamiltonian and Lie generators.
-        poly_cm_real = self.compute()
+        poly_cm_real = self.compute(form="center_manifold_real")
         _, poly_G_total, _ = self._get_partial_lie_results()
 
         config = _get_section_config(section_coord)
@@ -575,18 +625,60 @@ class CenterManifold:
         real_6d_cm[4] = real_4d_cm[1]  # p2
         real_6d_cm[5] = real_4d_cm[3]  # p3
 
-        complex_6d_cm = _solve_complex(real_6d_cm)
+        complex_6d_cm = _solve_complex(real_6d_cm, tol)
         expansions = _lie_expansion(
-            poly_G_total, self._max_degree, self._psi, self._clmo, 1e-30,
+            poly_G_total, self._max_degree, self._psi, self._clmo, tol,
             inverse=False, sign=1, restrict=False,
         )
         complex_6d = _evaluate_transform(expansions, complex_6d_cm, self._clmo)
-        real_6d = _solve_real(complex_6d)
-        local_6d = _realmodal2local(self._point, real_6d)
-        synodic_6d = self._local2synodic(self._point, local_6d)
+        real_6d = _solve_real(complex_6d, tol)
+        local_6d = _coordrealmodal2local(self._point, real_6d, tol)
+        synodic_6d = self._local2synodic(self._point, local_6d, tol)
 
         logger.info("CM to synodic transformation complete")
         return synodic_6d
+    
+    def cm(self, synodic_6d: np.ndarray, tol=1e-16) -> np.ndarray:
+        """Return 4-D centre-manifold coordinates (q2, p2, q3, p3) from 6-D synodic ICs.
+
+        This is the exact inverse of :py:meth:`ic` and therefore performs the
+        following steps in *reverse* order::
+
+            synodic -> local -> real modal -> complex modal -> Lie-inverse -> CM.
+
+        Parameters
+        ----------
+        synodic_6d : numpy.ndarray, shape (6,)
+            Synodic coordinates (X, Y, Z, Vx, Vy, Vz).
+
+        Returns
+        -------
+        numpy.ndarray, shape (4,)
+            Centre-manifold real coordinates ``[q2, p2, q3, p3]``.
+        """
+
+        local_6d = self._synodic2local(self._point, synodic_6d, tol)
+
+        real_modal_6d = _coordlocal2realmodal(self._point, local_6d, tol)
+
+        complex_modal_6d = _solve_complex(real_modal_6d, tol)
+
+        _, poly_G_total, _ = self._get_partial_lie_results()
+        expansions = _lie_expansion(poly_G_total, self._max_degree, self._psi, self._clmo,
+                                    tol, inverse=True, sign=-1, restrict=False)
+
+        complex_pnf_6d = _evaluate_transform(expansions, complex_modal_6d, self._clmo)
+        real_pnf_6d = _solve_real(complex_pnf_6d, tol)
+        real_cm_6d = self._restrict_coord_to_center_manifold(real_pnf_6d)
+
+        real_cm_4d = np.array([
+            real_cm_6d[1], # q2
+            real_cm_6d[4], # p2
+            real_cm_6d[2], # q3
+            real_cm_6d[5], # p3
+        ], dtype=np.float64)
+
+        return real_cm_4d
 
     def save(self, dir_path: str):
         r"""
