@@ -7,13 +7,12 @@ Usage example::
     from hiten.system.orbits import HaloOrbit, LyapunovOrbit
 """
 
-from .base import GenericOrbit, PeriodicOrbit, S, _CorrectionConfig
+from .base import GenericOrbit, PeriodicOrbit, S
 from .halo import HaloOrbit
 from .lyapunov import LyapunovOrbit
 from .vertical import VerticalOrbit
 
 __all__ = [
-    "_CorrectionConfig",
     "PeriodicOrbit",
     "GenericOrbit",
     "HaloOrbit",
