@@ -13,7 +13,7 @@ The module provides:
 * :pyclass:`GenericOrbit` - a minimal concrete implementation useful for
   arbitrary initial conditions when no analytical guess or specific correction
   is required.
-* Light-weight configuration containers (:pyclass:`_CorrectionConfig`) that 
+* Light-weight configuration containers (:pyclass:`_OrbitCorrectionConfig`) that 
   encapsulate user input for differential correction settings.
 
 References
@@ -21,24 +21,22 @@ References
 Szebehely, V. (1967). "Theory of Orbits - The Restricted Problem of Three
 Bodies".
 """
-
-from __future__ import annotations
-
 import os
 from abc import ABC, abstractmethod
 from enum import IntEnum
-from typing import (TYPE_CHECKING, Callable, Literal, NamedTuple, Optional,
-                    Sequence, Tuple)
+from typing import TYPE_CHECKING, Literal, Optional, Sequence, Tuple
 
 import numpy as np
 import numpy.typing as npt
 import pandas as pd
 
+from hiten.algorithms.corrector.correctors import _NewtonOrbitCorrector
+from hiten.algorithms.corrector.line import _LineSearchConfig
 from hiten.algorithms.dynamics.base import _propagate_dynsys
-from hiten.algorithms.dynamics.rtbp import _compute_stm, _stability_indices
+from hiten.algorithms.dynamics.rtbp import (_compute_monodromy, _compute_stm,
+                                            _stability_indices)
 from hiten.algorithms.dynamics.utils.energy import (crtbp_energy,
                                                     energy_to_jacobi)
-from hiten.algorithms.dynamics.utils.geometry import _find_y_zero_crossing
 from hiten.system.base import System
 from hiten.system.libration.base import LibrationPoint
 from hiten.utils.io import (_ensure_dir, _load_periodic_orbit,
@@ -49,56 +47,17 @@ from hiten.utils.plots import (animate_trajectories, plot_inertial_frame,
 
 if TYPE_CHECKING:
     from hiten.system.manifold import Manifold
+    from hiten.algorithms.corrector.interfaces import _OrbitCorrectionConfig
+    from hiten.algorithms.continuation.interfaces import _OrbitContinuationConfig
 
 
-class S(IntEnum): X=0; Y=1; Z=2; VX=3; VY=4; VZ=5
-
-
-class _CorrectionConfig(NamedTuple):
-    r"""
-    Settings that drive the differential correction routine.
-
-    The named-tuple is immutable and therefore safe to share across calls.
-
-    Parameters
-    ----------
-    residual_indices : tuple of int
-        Indices of the state vector used to build the residual vector
-        :math:`\mathbf R`.
-    control_indices : tuple of int
-        Indices of the state vector that are allowed to change so as to cancel
-        :math:`\mathbf R`.
-    extra_jacobian : callable or None, optional
-        Function returning an additional contribution that is subtracted from
-        the Jacobian before solving the linear system; useful when the event
-        definition introduces extra dependencies.
-    target : tuple of float, default ``(0.0,)``
-        Desired values for the residual components.
-    event_func : callable, default :pyfunc:`hiten.utils.geometry._find_y_zero_crossing`
-        Event used to terminate half-period propagation.
-    method : {"rk", "scipy", "symplectic", "adaptive"}, default "scipy"
-        _Integrator back-end to use when marching the variational equations.
-    order : int, default 8
-        Order for the custom integrators.
-    steps : int, default 2000
-        Number of fixed steps per half-period when *method* is not adaptive.
-    """
-    residual_indices: tuple[int, ...]
-    control_indices: tuple[int, ...]
-    extra_jacobian: Callable[[np.ndarray,np.ndarray], np.ndarray] | None = None
-    target: tuple[float, ...] = (0.0,)
-    event_func: Callable[...,tuple[float,np.ndarray]] = _find_y_zero_crossing
-
-    method: Literal["rk", "scipy", "symplectic", "adaptive"] = "scipy"
-    order: int = 8
-    steps: int = 2000
-
-
-class _ContinuationConfig(NamedTuple):
-    state: S | None
-    amplitude: bool = False
-    getter: Callable[["PeriodicOrbit"], float] | None = None
-    extra_params: dict | None = None
+class S(IntEnum): 
+    X=0
+    Y=1
+    Z=2
+    VX=3
+    VY=4
+    VZ=5
 
 
 class PeriodicOrbit(ABC):
@@ -144,7 +103,7 @@ class PeriodicOrbit(ABC):
     Notes
     -----
     Instantiating the class does **not** perform any propagation. Users must
-    call :pyfunc:`PeriodicOrbit.differential_correction` (or manually set
+    call :pyfunc:`PeriodicOrbit.correct` (or manually set
     :pyattr:`period`) followed by :pyfunc:`PeriodicOrbit.propagate`.
     """
     
@@ -297,6 +256,8 @@ class PeriodicOrbit(ABC):
                 self._times = None
             if hasattr(self, "_stability_info"):
                 self._stability_info = None
+            if hasattr(self, "_monodromy"):
+                self._monodromy = None
 
             logger.info("Period updated, cached trajectory, times and stability information cleared")
 
@@ -353,6 +314,22 @@ class PeriodicOrbit(ABC):
             The Jacobi constant value
         """
         return energy_to_jacobi(self.energy)
+    
+    @property
+    def monodromy(self) -> np.ndarray:
+        r"""
+        Compute the monodromy matrix of the orbit.
+        
+        Returns
+        -------
+        numpy.ndarray
+            The monodromy matrix
+        """
+        if self.period is None:
+            raise ValueError("Period must be set before computing monodromy")
+        
+        Phi = _compute_monodromy(self.libration_point._var_eq_system, self.initial_state, self.period)
+        return Phi
 
     @property
     @abstractmethod
@@ -361,13 +338,13 @@ class PeriodicOrbit(ABC):
 
     @property
     @abstractmethod
-    def _correction_config(self) -> _CorrectionConfig:
+    def _correction_config(self) -> "_OrbitCorrectionConfig":
         """Provides the differential correction configuration for this orbit family."""
         pass
 
     @property
     @abstractmethod
-    def _continuation_config(self) -> _ContinuationConfig:
+    def _continuation_config(self) -> "_OrbitContinuationConfig":
         """Default parameter for family continuation (must be overridden)."""
         raise NotImplementedError
 
@@ -381,95 +358,47 @@ class PeriodicOrbit(ABC):
         self._times = None
         self._stability_info = None
         self._period = None
+        self._monodromy = None
         logger.debug("Reset computed orbit properties due to state change")
 
     @abstractmethod
     def _initial_guess(self, **kwargs):
         pass
 
-    def _compute_correction_step(self, current_state: np.ndarray, t_event: float, x_event: np.ndarray) -> np.ndarray:
-        """Compute the correction step `delta` for the differential corrector."""
-        cfg = self._correction_config
-        
-        _, _, Phi, _ = _compute_stm(
-            self.libration_point._var_eq_system, current_state, t_event, 
-            steps=cfg.steps, method=cfg.method, order=cfg.order
-        )
-
-        J = Phi[np.ix_(cfg.residual_indices, cfg.control_indices)]
-
-        if cfg.extra_jacobian is not None:
-            J -= cfg.extra_jacobian(x_event, Phi)
-
-        if abs(np.linalg.det(J)) < 1e-12:
-            logger.warning(f"Jacobian determinant is small ({np.linalg.det(J):.2e}), adding regularization.")
-            J += np.eye(J.shape[0]) * 1e-12
-        
-        R = x_event[list(cfg.residual_indices)] - np.array(cfg.target)
-        delta = np.linalg.solve(J, -R)
-        
-        return delta
-
-    def _apply_correction(self, state: np.ndarray, delta: np.ndarray) -> np.ndarray:
-        """Apply the correction `delta` to the appropriate state variables."""
-        cfg = self._correction_config
-        state[list(cfg.control_indices)] += delta
-        return state
-
-    def differential_correction(
+    def correct(
             self,
             *,
-            tol: float = 1e-10,
-            max_attempts: int = 25,
-            forward: int = 1
+            tol: float | None = None,
+            max_attempts: int | None = None,
+            forward: int | None = None,
+            max_delta: float | None = None,
+            line_search_config: _LineSearchConfig | bool | None = None,
+            finite_difference: bool | None = None,
         ) -> tuple[np.ndarray, float]:
+        """Differential correction wrapper.
+
+        This method now delegates the heavy lifting to the generic
+        :class:`hiten.algorithms.corrector.newton._NewtonOrbitCorrector` which
+        implements a robust Newton-Armijo scheme.
         """
-        Perform differential correction to find a periodic orbit.
-        
-        This method uses the configuration provided by `self._correction_config`
-        to iteratively refine the `initial_state` until it converges to a
-        periodic orbit.
-
-        Parameters
-        ----------
-        tol : float, optional
-            Tolerance for the correction, measured by the infinity norm of the
-            residual vector. Default is 1e-10.
-        max_attempts : int, optional
-            Maximum number of correction attempts. Default is 25.
-        forward : int, optional
-            Direction of propagation (1 for forward, -1 for backward). Default is 1.
-
-        Returns
-        -------
-        tuple
-            A tuple containing the corrected initial state and the half-period
-            of the resulting orbit `(state, period/2)`.
-
-        Raises
-        ------
-        RuntimeError
-            If the correction does not converge within `max_attempts`.
-        """
-        X0 = self.initial_state.copy()
+        # Use per-family correction configuration as fallback defaults
         cfg = self._correction_config
 
-        for k in range(max_attempts + 1):
-            t_ev, X_ev = cfg.event_func(dynsys=self.system._dynsys, x0=X0, forward=forward)
-            R = X_ev[list(cfg.residual_indices)] - np.array(cfg.target)
+        _tol = tol if tol is not None else cfg.tol
+        _max_attempts = max_attempts if max_attempts is not None else cfg.max_attempts
+        _forward = forward if forward is not None else cfg.forward
+        _line_search_cfg = line_search_config if line_search_config is not None else cfg.line_search_config
+        _max_delta = max_delta if max_delta is not None else cfg.max_delta
+        _finite_difference = finite_difference if finite_difference is not None else cfg.finite_difference
 
-            if np.linalg.norm(R, ord=np.inf) < tol:
-                self._reset()
-                self._initial_state = X0
-                self._period = 2 * t_ev
-                logger.info(f"Differential correction converged after {k} iterations.")
-                return X0, t_ev
-
-            delta = self._compute_correction_step(X0, t_ev, X_ev)
-            X0 = self._apply_correction(X0, delta)
-            logger.info(f"Correction attempt {k+1}/{max_attempts}: |R|={np.linalg.norm(R):.2e}, delta={delta}")
-
-        raise RuntimeError(f"Differential correction did not converge after {max_attempts} attempts.")
+        return _NewtonOrbitCorrector(line_search_config=_line_search_cfg).correct(
+            self,
+            tol=_tol,
+            max_attempts=_max_attempts,
+            forward=_forward,
+            max_delta=_max_delta,
+            finite_difference=_finite_difference,
+        )
 
     def propagate(self, steps: int = 1000, method: Literal["rk", "scipy", "symplectic", "adaptive"] = "scipy", order: int = 8) -> Tuple[npt.NDArray[np.float64], npt.NDArray[np.float64]]:
         r"""
@@ -529,10 +458,10 @@ class PeriodicOrbit(ABC):
         
         logger.info(f"Computing stability for orbit with period {self.period}")
         # Compute STM over one period
-        _, _, monodromy, _ = _compute_stm(self.libration_point._var_eq_system, self.initial_state, self.period)
+        _, _, Phi, _ = _compute_stm(self.libration_point._var_eq_system, self.initial_state, self.period)
         
         # Analyze stability
-        stability = _stability_indices(monodromy)
+        stability = _stability_indices(Phi)
         self._stability_info = stability
         
         is_stable = np.all(np.abs(stability[0]) <= 1.0)
@@ -649,28 +578,29 @@ class GenericOrbit(PeriodicOrbit):
     
     def __init__(self, libration_point: LibrationPoint, initial_state: Optional[Sequence[float]] = None):
         super().__init__(libration_point, initial_state)
-        self._custom_correction_config: Optional[_CorrectionConfig] = None
-        self._custom_continuation_config: Optional[_ContinuationConfig] = None
+        self._custom_correction_config: Optional["_OrbitCorrectionConfig"] = None
+        self._custom_continuation_config: Optional["_OrbitContinuationConfig"] = None
         if self._period is None:
             self._period = np.pi
 
         self._amplitude = None
 
     @property
-    def correction_config(self) -> Optional[_CorrectionConfig]:
+    def correction_config(self) -> Optional["_OrbitCorrectionConfig"]:
         """
         Get or set the user-defined differential correction configuration.
 
-        This property must be set to a valid :py:class:`_CorrectionConfig`
-        instance before calling :py:meth:`differential_correction` on a
+        This property must be set to a valid :py:class:`_OrbitCorrectionConfig`
+        instance before calling :py:meth:`correct` on a
         :py:class:`GenericOrbit` object.
         """
         return self._custom_correction_config
 
     @correction_config.setter
-    def correction_config(self, value: Optional[_CorrectionConfig]):
-        if value is not None and not isinstance(value, _CorrectionConfig):
-            raise TypeError("correction_config must be an instance of _CorrectionConfig or None.")
+    def correction_config(self, value: Optional["_OrbitCorrectionConfig"]):
+        from hiten.algorithms.corrector.interfaces import _OrbitCorrectionConfig
+        if value is not None and not isinstance(value, _OrbitCorrectionConfig):
+            raise TypeError("correction_config must be an instance of _OrbitCorrectionConfig or None.")
         self._custom_correction_config = value
 
     @property
@@ -678,7 +608,7 @@ class GenericOrbit(PeriodicOrbit):
         return np.nan
 
     @property
-    def _correction_config(self) -> _CorrectionConfig:
+    def _correction_config(self) -> "_OrbitCorrectionConfig":
         """
         Provides the differential correction configuration.
 
@@ -689,7 +619,7 @@ class GenericOrbit(PeriodicOrbit):
             return self.correction_config
         raise NotImplementedError(
             "Differential correction is not defined for a GenericOrbit unless the "
-            "`correction_config` property is set with a valid _CorrectionConfig."
+            "`correction_config` property is set with a valid _OrbitCorrectionConfig."
         )
 
     @property
@@ -702,18 +632,19 @@ class GenericOrbit(PeriodicOrbit):
         self._amplitude = value
 
     @property
-    def continuation_config(self) -> Optional[_ContinuationConfig]:
+    def continuation_config(self) -> Optional["_OrbitContinuationConfig"]:
         """Get or set the continuation parameter for this orbit."""
         return self._custom_continuation_config
 
     @continuation_config.setter
-    def continuation_config(self, cfg: Optional[_ContinuationConfig]):
-        if cfg is not None and not isinstance(cfg, _ContinuationConfig):
-            raise TypeError("continuation_config must be a _ContinuationConfig instance or None")
+    def continuation_config(self, cfg: Optional["_OrbitContinuationConfig"]):
+        from hiten.algorithms.continuation.interfaces import _OrbitContinuationConfig
+        if cfg is not None and not isinstance(cfg, _OrbitContinuationConfig):
+            raise TypeError("continuation_config must be a _OrbitContinuationConfig instance or None")
         self._custom_continuation_config = cfg
 
     @property
-    def _continuation_config(self) -> _ContinuationConfig:  # used by engines
+    def _continuation_config(self) -> "_OrbitContinuationConfig":  # used by engines
         if self._custom_continuation_config is None:
             raise NotImplementedError(
                 "GenericOrbit requires 'continuation_config' to be set before using continuation engines."
